@@ -4,8 +4,8 @@
 
 ;; Author: Alvaro Ramirez https://xenodium.com
 ;; URL: https://github.com/xenodium/acp.el
-;; Package-Version: 20260201.1911
-;; Package-Revision: 771e01e8605c
+;; Package-Version: 20260213.1849
+;; Package-Revision: e5dec95452de
 ;; Package-Requires: ((emacs "28.1"))
 
 (defconst acp-package-version "0.9.1")
@@ -467,19 +467,26 @@ See https://agentclientprotocol.com/protocol/schema#authenticaterequest."
                         (when method
                           `((authMethod . ,method)))))))
 
-(cl-defun acp-make-session-new-request (&key cwd mcp-servers)
+(cl-defun acp-make-session-new-request (&key cwd mcp-servers meta)
   "Instantiate a \"session/new\" request.
 
 CWD is the current working directory for the session.
 MCP-SERVERS is a list of MCP servers to use.
+META is an optional alist of metadata to pass to the agent.
+  Supported keys include:
+  - `systemPrompt': Either a string (replaces default) or
+    an alist with key `append' containing a string to append
+    to the default system prompt.
 
 See https://agentclientprotocol.com/protocol/schema#newsessionrequest
 and https://agentclientprotocol.com/protocol/schema#newsessionresponse."
   (unless cwd
     (error ":cwd is required"))
   `((:method . "session/new")
-    (:params . ((cwd . ,(expand-file-name cwd))
-                (mcpServers . ,(or mcp-servers []))))))
+    ;; directory-file-name removes any trailing /
+    (:params . ((cwd . ,(directory-file-name (expand-file-name cwd)))
+                (mcpServers . ,(or mcp-servers []))
+                ,@(when meta `((_meta . ,meta)))))))
 
 (cl-defun acp-make-session-prompt-request (&key session-id prompt)
   "Instantiate a \"session/prompt\" request.
@@ -530,6 +537,75 @@ See https://docs.claude.com/en/api/agent-sdk/typescript"
     (:params . ((sessionId . ,session-id)
                 (modelId . ,model-id)))))
 
+(cl-defun acp-make-session-resume-request (&key session-id cwd mcp-servers)
+  "Instantiate a \"session/resume\" request.
+
+SESSION-ID is the ID of the session to resume.
+CWD is the current working directory for the resumed session.
+MCP-SERVERS is an optional list of MCP servers to use.
+
+This method resumes an existing session without returning previous messages
+\(unlike `session/load').  Only available if the agent advertises the
+`session.resume' capability.
+
+Note: This is an unstable ACP feature.
+
+See https://agentclientprotocol.com/rfds/session-resume."
+  (unless session-id
+    (error ":session-id is required"))
+  (unless cwd
+    (error ":cwd is required"))
+  `((:method . "session/resume")
+    (:params . ((sessionId . ,session-id)
+                ;; directory-file-name removes any trailing /
+                (cwd . ,(directory-file-name (expand-file-name cwd)))
+                (mcpServers . ,(or mcp-servers []))))))
+
+(cl-defun acp-make-session-list-request (&key cwd)
+  "Instantiate a \"session/list\" request.
+
+CWD is the current working directory used to filter sessions.
+
+Note: This is an unstable ACP feature.
+
+See https://agentclientprotocol.com/rfds/session-list."
+  (unless cwd
+    (error ":cwd is required"))
+  `((:method . "session/list")
+    ;; directory-file-name removes any trailing /
+    (:params . ((cwd . ,(directory-file-name (expand-file-name cwd)))))))
+
+(cl-defun acp-make-session-load-request (&key session-id cwd mcp-servers)
+  "Instantiate a \"session/load\" request.
+
+SESSION-ID is the ID of the session to load.
+CWD is the current working directory for the loaded session.
+MCP-SERVERS is an optional list of MCP servers to use.
+
+See https://agentclientprotocol.com/protocol/schema#session-load."
+  (unless session-id
+    (error ":session-id is required"))
+  (unless cwd
+    (error ":cwd is required"))
+  `((:method . "session/load")
+    (:params . ((sessionId . ,session-id)
+                ;; directory-file-name removes any trailing /
+                (cwd . ,(directory-file-name (expand-file-name cwd)))
+                (mcpServers . ,(or mcp-servers []))))))
+
+(cl-defun acp-make-session-delete-request (&key session-id)
+  "Instantiate a \"session/delete\" request.
+
+SESSION-ID is the ID of the session to delete.
+
+Note: This is an unstable ACP feature.
+
+See https://agentclientprotocol.com/rfds/session-delete."
+  (unless session-id
+    (error ":session-id is required"))
+  `((:method . "session/delete")
+    (:params . ((sessionId . ,session-id)))))
+
 (cl-defun acp-make-session-request-permission-response (&key request-id option-id cancelled)
   "Instantiate a \"session/request_permission\" response.
 
